<?php
/*
Plugin Name: Custom Popup
Plugin URI: https://www.tecnologiadigitale.net
Description: Mostra un popup personalizzato sulla home page.
Version: 1.8
Author: Dario
Author URI: https://www.tecnologiadigitale.net
*/

if (!defined('ABSPATH')) {
    exit;
}

global $custom_popup_db_version;
$custom_popup_db_version = '1.0';

// Crea la tabella per memorizzare i messaggi popup
function custom_popup_install() {
    global $wpdb;
    global $custom_popup_db_version;

    $table_name = $wpdb->prefix . 'custom_popup_messages';
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        message text NOT NULL,
        start_date date NOT NULL,
        end_date date NOT NULL,
        start_time time NOT NULL,
        end_time time NOT NULL,
        duration int NOT NULL,
        text_color varchar(7) DEFAULT '#000000' NOT NULL,
        bubble_color varchar(7) DEFAULT '#ffffff' NOT NULL,
        position varchar(20) DEFAULT 'center' NOT NULL,
        show_always tinyint(1) DEFAULT 0 NOT NULL,
        active tinyint(1) DEFAULT 0 NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);

    add_option('custom_popup_db_version', $custom_popup_db_version);
}

register_activation_hook(__FILE__, 'custom_popup_install');

// Carica script e stili
function custom_popup_enqueue_scripts() {
    wp_enqueue_script('custom-popup-js', plugin_dir_url(__FILE__) . 'js/custom-popup.js', array('jquery'), '1.0', true);

    $active_popup = custom_popup_get_active_message();
    $popup_data = array(
        'message' => $active_popup ? $active_popup->message : '',
        'duration' => $active_popup ? $active_popup->duration : 10,
        'textColor' => $active_popup ? $active_popup->text_color : '#000000',
        'bubbleColor' => $active_popup ? $active_popup->bubble_color : '#ffffff',
        'position' => $active_popup ? $active_popup->position : 'center',
        'showAlways' => $active_popup ? $active_popup->show_always : 0
    );

    wp_localize_script('custom-popup-js', 'popupData', $popup_data);
    wp_enqueue_style('custom-popup-css', plugin_dir_url(__FILE__) . 'css/custom-popup.css');
}
add_action('wp_enqueue_scripts', 'custom_popup_enqueue_scripts');

// Recupera il messaggio popup attivo
function custom_popup_get_active_message() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'custom_popup_messages';

    $current_date = current_time('Y-m-d');
    $current_time = current_time('H:i:s');

    return $wpdb->get_row($wpdb->prepare(
        "SELECT * FROM $table_name WHERE active = 1 AND start_date <= %s AND end_date >= %s AND start_time <= %s AND end_time >= %s LIMIT 1",
        $current_date, $current_date, $current_time, $current_time
    ));
}

// Aggiungi voci di menu di amministrazione
function custom_popup_admin_menu() {
    add_menu_page('Messaggi Popup Personalizzati', 'Popup Personalizzati', 'manage_options', 'custom-popup-messages', 'custom_popup_messages_page', 'dashicons-format-chat');
}
add_action('admin_menu', 'custom_popup_admin_menu');

// Gestisci la pagina di gestione dei messaggi
function custom_popup_messages_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'custom_popup_messages';

    $message_status = '';

    // Gestisci eliminazione del messaggio
    if (isset($_GET['delete'])) {
        $id = intval($_GET['delete']);
        $wpdb->delete($table_name, array('id' => $id));
        $message_status = 'deleted';
    }

    // Controlla se si sta modificando un messaggio esistente
    $edit = isset($_GET['edit']) ? intval($_GET['edit']) : 0;
    $message = null;

    if ($edit) {
        $message = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE id = %d", $edit));
    }

    // Gestisci l'invio del form
    if (isset($_POST['save_message'])) {
        $popup_message = sanitize_text_field($_POST['popup_message']);
        $start_date = sanitize_text_field($_POST['start_date']);
        $end_date = sanitize_text_field($_POST['end_date']);
        $start_time = sanitize_text_field($_POST['start_time']);
        $end_time = sanitize_text_field($_POST['end_time']);
        $duration = intval($_POST['duration']);
        $text_color = sanitize_hex_color($_POST['text_color']);
        $bubble_color = sanitize_hex_color($_POST['bubble_color']);
        $position = sanitize_text_field($_POST['position']);
        $show_always = isset($_POST['show_always']) ? 1 : 0;
        $active = isset($_POST['active']) ? 1 : 0;

        if ($edit) {
            // Aggiorna il messaggio esistente
            $wpdb->update($table_name, array(
                'message' => $popup_message,
                'start_date' => $start_date,
                'end_date' => $end_date,
                'start_time' => $start_time,
                'end_time' => $end_time,
                'duration' => $duration,
                'text_color' => $text_color,
                'bubble_color' => $bubble_color,
                'position' => $position,
                'show_always' => $show_always,
                'active' => $active
            ), array('id' => $edit));
            $message_status = 'updated';
        } else {
            // Inserisci un nuovo messaggio
            $wpdb->insert($table_name, array(
                'message' => $popup_message,
                'start_date' => $start_date,
                'end_date' => $end_date,
                'start_time' => $start_time,
                'end_time' => $end_time,
                'duration' => $duration,
                'text_color' => $text_color,
                'bubble_color' => $bubble_color,
                'position' => $position,
                'show_always' => $show_always,
                'active' => $active
            ));
            $message_status = 'inserted';
        }

        // Assicura che solo un messaggio sia attivo
        if ($active) {
            $wpdb->query($wpdb->prepare("UPDATE $table_name SET active = 0 WHERE id != %d", $edit ? $edit : $wpdb->insert_id));
        }
    }

    $messages = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id DESC");

    ?>
    <div class="wrap">
        <h1>Tutti i Messaggi Popup</h1>
        <?php if ($message_status == 'inserted') : ?>
            <div class="notice notice-success is-dismissible">
                <p>Il nuovo messaggio popup è stato aggiunto con successo!</p>
            </div>
        <?php elseif ($message_status == 'updated') : ?>
            <div class="notice notice-success is-dismissible">
                <p>Il messaggio popup è stato aggiornato con successo!</p>
            </div>
        <?php elseif ($message_status == 'deleted') : ?>
            <div class="notice notice-success is-dismissible">
                <p>Il messaggio popup è stato eliminato con successo!</p>
            </div>
        <?php endif; ?>
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Messaggio</th>
                    <th>Data Inizio</th>
                    <th>Data Fine</th>
                    <th>Ora Inizio</th>
                    <th>Ora Fine</th>
                    <th>Durata (secondi)</th>
                    <th>Colore Testo</th>
                    <th>Colore Sfondo</th>
                    <th>Posizione</th>
                    <th>Mostra Sempre</th>
                    <th>Attivo</th>
                    <th>Azioni</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($messages as $message) : ?>
                <tr>
                    <td><?php echo esc_html($message->id); ?></td>
                    <td><?php echo esc_html($message->message); ?></td>
                    <td><?php echo esc_html($message->start_date); ?></td>
                    <td><?php echo esc_html($message->end_date); ?></td>
                    <td><?php echo esc_html($message->start_time); ?></td>
                    <td><?php echo esc_html($message->end_time); ?></td>
                    <td><?php echo esc_html($message->duration); ?> secondi</td>
                    <td><span style="background-color: <?php echo esc_html($message->text_color); ?>; color: #ffffff; padding: 2px 5px;"><?php echo esc_html($message->text_color); ?></span></td>
                    <td><span style="background-color: <?php echo esc_html($message->bubble_color); ?>; color: #000000; padding: 2px 5px;"><?php echo esc_html($message->bubble_color); ?></span></td>
                    <td><?php echo esc_html($message->position); ?></td>
                    <td><?php echo $message->show_always ? 'Sì' : 'No'; ?></td>
                    <td><?php echo $message->active ? 'Sì' : 'No'; ?></td>
                    <td>
                        <a href="<?php echo admin_url('admin.php?page=custom-popup-messages&edit=' . $message->id); ?>">Modifica</a> |
                        <a href="<?php echo admin_url('admin.php?page=custom-popup-messages&delete=' . $message->id); ?>" onclick="return confirm('Sei sicuro di voler eliminare questo messaggio?')">Elimina</a>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <h2><?php echo $edit ? 'Modifica Messaggio Popup' : 'Aggiungi Nuovo Messaggio Popup'; ?></h2>
        <form method="post" action="">
            <input type="hidden" name="id" value="<?php echo $edit ? esc_html($message->id) : ''; ?>">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Messaggio Popup</th>
                    <td><textarea name="popup_message" class="large-text" rows="3"><?php echo $edit ? esc_html($message->message) : ''; ?></textarea></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Data Inizio</th>
                    <td><input type="date" name="start_date" value="<?php echo $edit ? esc_html($message->start_date) : ''; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Data Fine</th>
                    <td><input type="date" name="end_date" value="<?php echo $edit ? esc_html($message->end_date) : ''; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Ora Inizio</th>
                    <td><input type="time" name="start_time" value="<?php echo $edit ? esc_html($message->start_time) : ''; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Ora Fine</th>
                    <td><input type="time" name="end_time" value="<?php echo $edit ? esc_html($message->end_time) : ''; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Durata (secondi)</th>
                    <td><input type="number" name="duration" value="<?php echo $edit ? esc_html($message->duration) : '10'; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Colore Testo</th>
                    <td><input type="color" name="text_color" value="<?php echo $edit ? esc_html($message->text_color) : '#000000'; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Colore Sfondo</th>
                    <td><input type="color" name="bubble_color" value="<?php echo $edit ? esc_html($message->bubble_color) : '#ffffff'; ?>" required /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Posizione</th>
                    <td>
                        <select name="position">
                            <option value="center" <?php selected($edit ? $message->position : 'center', 'center'); ?>>Centro</option>
                            <option value="top-left" <?php selected($edit ? $message->position : '', 'top-left'); ?>>In alto a sinistra</option>
                            <option value="top-right" <?php selected($edit ? $message->position : '', 'top-right'); ?>>In alto a destra</option>
                            <option value="bottom-left" <?php selected($edit ? $message->position : '', 'bottom-left'); ?>>In basso a sinistra</option>
                            <option value="bottom-right" <?php selected($edit ? $message->position : '', 'bottom-right'); ?>>In basso a destra</option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Mostra Sempre</th>
                    <td><input type="checkbox" name="show_always" <?php checked($edit && $message->show_always); ?>></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Attivo</th>
                    <td><input type="checkbox" name="active" <?php echo $edit && $message->active ? 'checked' : ''; ?>></td>
                </tr>
            </table>
            <?php submit_button($edit ? 'Aggiorna Messaggio' : 'Salva Messaggio', 'primary', 'save_message'); ?>
        </form>
    </div>
    <?php
}

// Aggiungi metadati del plugin
function custom_popup_plugin_meta($links, $file) {
    if ($file == plugin_basename(__FILE__)) {
        $links[] = '<a href="https://www.tecnologiadigitale.net">Sito Web</a>';
        $links[] = '<a href="https://www.tecnologiadigitale.net">Info</a>';
    }
    return $links;
}
add_filter('plugin_action_links', 'custom_popup_plugin_meta', 10, 2);

// Gestisci la disinstallazione del plugin
function custom_popup_uninstall() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'custom_popup_messages';
    $wpdb->query("DROP TABLE IF EXISTS $table_name");

    delete_option('custom_popup_db_version');
    delete_option('custom_popup_position');
    delete_option('custom_popup_show_always');
}
register_uninstall_hook(__FILE__, 'custom_popup_uninstall');
?>